@@ -11,6 +11,8 @@ class Component:
         """
         self.game_object = None  # Set when attached to a GameObject
         self.active = True
+        self.is_runtime = False
+        self.has_started = False
 
     def start(self) -> None:
         """
@@ -73,3 +75,7 @@ class Component:
         Override in subclasses for cleanup logic.
         """
         pass
+
+    def exists(self):
+        """Returns True if the GameObject exists in the scene"""
+        return self.game_object.exists()
\ No newline at end of file
