@@ -1,5 +1,4 @@
 from cogworks.component import Component
-from cogworks.pygame_wrappers.event_manager import EventManager
 from cogworks.pygame_wrappers.window import Window
 
 
@@ -7,27 +6,8 @@ class Camera(Component):
     def __init__(self):
         super().__init__()
         self.offset_x = 0
-        self.offset_y = 200
+        self.offset_y = 0
         self.zoom = 1.0  # 1.0 = normal, <1.0 = zoom out, >1.0 = zoom in
-        self.surface_width, self.surface_height = Window.get_instance().get_size()
-
-
-    def on_enabled(self):
-        # Subscribe to window resize events
-        EventManager.get_instance().subscribe(self.handle_window_event)
-
-    def on_disabled(self):
-        EventManager.get_instance().unsubscribe(self.handle_window_event)
-
-    def on_remove(self) -> None:
-        EventManager.get_instance().unsubscribe(self.handle_window_event)
-
-    def handle_window_event(self, event):
-        """Update surface size on window resize."""
-        import pygame
-        if event.type == pygame.VIDEORESIZE:
-            self.surface_width = event.w
-            self.surface_height = event.h
 
     def move(self, dx, dy):
         """Move the camera by a given delta."""
@@ -48,7 +28,7 @@ class Camera(Component):
             tuple: (world_x, world_y)
         """
         # Screen positions
-        sw, sh = self.surface_width, self.surface_height
+        sw, sh = Window.get_instance().get_size()
         points = {
             "center": (sw / 2, sh / 2),
             "topleft": (0, 0),
@@ -99,8 +79,7 @@ class Camera(Component):
         self.offset_x = x - (screen_width / 2) / self.zoom
         self.offset_y = y - (screen_height / 2) / self.zoom
 
-    def is_visible(self, x: float, y: float, width: float, height: float,
-                   tolerance: float = None) -> bool:
+    def is_visible(self, x: float, y: float, width: float, height: float, tolerance: float = 500) -> bool:
         """
         Determine if a rectangle (sprite) is visible on the camera surface.
 
@@ -109,17 +88,12 @@ class Camera(Component):
             y (float): World Y position of the sprite center.
             width (float): Width of the sprite after scaling/zoom.
             height (float): Height of the sprite after scaling/zoom.
-            tolerance (float, optional): Extra buffer in pixels to consider visible. If None, calculated dynamically.
-
+            tolerance (float): The tolerance
         Returns:
             bool: True if the sprite is (partially) visible on camera, False if completely outside.
         """
         top, bottom, left, right = self.get_bounds()
 
-        if tolerance is None:
-            max_dim = max(width, height)
-            tolerance = max_dim * 0.5 if max_dim > 200 else 10
-
         obj_left = x - width / 2
         obj_right = x + width / 2
         obj_top = y - height / 2
@@ -131,10 +105,11 @@ class Camera(Component):
 
     def get_bounds(self):
         """
-        Returns the current camera bounds in world coordinates as (left, top, right, bottom).
+        Returns the current camera bounds in world coordinates as (top, bottom, left, right).
         """
+        w, h = Window.get_instance().get_size()
         left = self.offset_x
         top = self.offset_y
-        right = self.offset_x + self.surface_width / self.zoom
-        bottom = self.offset_y + self.surface_height / self.zoom
+        right = self.offset_x + w / self.zoom
+        bottom = self.offset_y + h/ self.zoom
         return top, bottom, left, right
