@@ -1,4 +1,5 @@
 import pymunk
+from operator import attrgetter
 
 from cogworks.components.camera import Camera
 from cogworks.game_object import GameObject
@@ -19,11 +20,9 @@ class Scene:
         Args:
             name (str): The name of the scene.
         """
-        self._needs_sort = False
+        self.has_started = False
         self.start_states = None
         self.name = name
-        self.game_objects: list[GameObject] = []
-        self.start_game_objects: list[GameObject] = []
 
         self.engine = None
 
@@ -31,146 +30,143 @@ class Scene:
         self.camera = GameObject("Camera")
         self.camera_component = Camera()
         self.camera.add_component(self.camera_component)
+        self.camera.scene = self
+
+        self.initial_objects: list[GameObject] = [self.camera]
+        self.runtime_objects: list[GameObject] = []
+
+        # Cache combined sorted list for updates and rendering
+        self.sorted_objects: list[GameObject] = self.initial_objects + self.runtime_objects
 
         self.physics_space = pymunk.Space()
         self.gravity = gravity
         self.physics_space.gravity = self.gravity
         self.trigger_collision_manager = TriggerCollisionManager()
 
-
     def start(self):
-        """
-        Start the scene by adding the default camera GameObject.
-        """
-        self.start_game_objects = self.game_objects.copy()
-
-        self.add_game_object(self.camera)
-
-        # Start each original game object
-        for go in self.game_objects:
+        self.has_started = True
+        # Start each initial game object
+        for go in self.initial_objects:
             go.enable()
             go.start()
+        self._sort_objects()
 
-    def add_game_object(self, game_object: GameObject) -> None:
-        """
-        Add a GameObject to the scene, set its scene reference, and call its start method.
+    def stop(self):
+        self._cleanup()
+        self.has_started = False
 
-        Args:
-            game_object (GameObject): The GameObject to add.
-        """
-        self.game_objects.append(game_object)
-        game_object.scene = self
-        self._needs_sort = True
-
-    def remove_game_object(self, game_object: GameObject) -> None:
-        """
-        Remove a GameObject from the scene and optionally call `on_remove` on its components.
-
-        Args:
-            game_object (GameObject): The GameObject to remove.
-        """
-        if game_object in self.game_objects:
-            for comp in game_object.components:
-                if hasattr(comp, "on_remove"):
-                    comp.on_remove()
-            self.game_objects.remove(game_object)
-            self._needs_sort = True
-
-    def get_components(self, component_type):
-        """
-        Get all components of a given type from all GameObjects in the scene.
-
-        Args:
-            component_type (type): The class/type of component to search for.
-
-        Returns:
-            list: A list of matching components.
-        """
-        results = []
-        for obj in self.game_objects:
-            for comp in obj.components:
-                if isinstance(comp, component_type):
-                    results.append(comp)
-        return results
-
-    def update(self, dt: float) -> None:
-        """
-        Update all GameObjects and CollisionManagers in the scene.
-
-        Args:
-            dt (float): Delta time since last frame.
-        """
-        for obj in self.game_objects:
-            obj.update(dt)
-
-        if self.trigger_collision_manager:
-            self.trigger_collision_manager.update(dt)
-
-    def fixed_update(self, dt: float) -> None:
-        """
-        Fixed timestep update for physics or deterministic logic.
-        Calls `fixed_update` on GameObjects and their components if implemented.
-
-        Args:
-            dt (float): Fixed delta time.
-        """
-
-        self.physics_space.step(dt)
-
-        for obj in self.game_objects:
-            if hasattr(obj, "fixed_update"):
-                obj.fixed_update(dt)
-            for comp in obj.components:
-                if hasattr(comp, "fixed_update"):
-                    comp.fixed_update(dt)
-
-    def render(self, surface) -> None:
-        """
-        Render all GameObjects in the scene to the given surface in order of z_index.
-        GameObjects without a z_index attribute default to 0.
-
-        Args:
-            surface: The surface to render onto (e.g., a Pygame surface).
-        """
-        # Sort game objects by z_index (default 0)
-        if self._needs_sort:
-            self.game_objects.sort(key=lambda obj: obj.z_index)
-            self._needs_sort = False
-
-        for obj in self.game_objects:
-            obj.render(surface)
-
-    def restart(self):
+    def _cleanup(self):
         # Create a new physics space
         self.physics_space = pymunk.Space()
         self.physics_space.gravity = self.gravity
 
-        for go in self.game_objects:
-            go.reset_to_start()
+        # Destroy and cleanup runtime GameObjects
+        for go in self.runtime_objects:
+            go.destroy()
+            go.cleanup()
+        self.runtime_objects.clear()
 
-    def stop_scene(self):
-        for go in self.game_objects:
+        # Disable and clean up initial GameObjects
+        for go in self.initial_objects:
+            go.cleanup()
             go.disable()
 
-    def save_start_states(self):
-        self.start_states = {}
+        # Clear collision manager
+        self.trigger_collision_manager.clear()
 
-        def save_go_state(go):
-            transform = go.get_component("Transform")
-            if transform:
-                self.start_states[go.uuid] = {
-                    "local_x": transform.local_x,
-                    "local_y": transform.local_y,
-                    "local_scale_x": transform.local_scale_x,
-                    "local_scale_y": transform.local_scale_y,
-                    "local_rotation": transform.local_rotation,
-                }
-            # Recurse through children
-            for child in getattr(go, "children", []):
-                save_go_state(child)
+        self._sort_objects()  # refresh sorted_objects
 
-        for go in self.game_objects:
-            save_go_state(go)
+    def restart(self):
+        self.stop()
+        self.start()
+
+    def add_game_object(self, game_object: GameObject) -> None:
+        """
+        Add a *initial GameObject to the scene
+
+        Args:
+            game_object (GameObject): The GameObject to add.
+        """
+        if self.has_started:
+            raise RuntimeError("Scene already started, use instantiate_game_object instead")
+        game_object.scene = self
+        self.initial_objects.append(game_object)
+        self._sort_objects()
+
+    def instantiate_game_object(self, game_object: GameObject) -> None:
+        """
+        Instantiate a *runtime GameObject to the scene, set its scene reference, and call its start method.
+
+        Args:
+            game_object (GameObject): The GameObject to add.
+        """
+        if not self.has_started:
+            raise RuntimeError("Scene hasn't started, use add_game_object instead")
+        game_object.scene = self
+        game_object.start()
+        self.runtime_objects.append(game_object)
+        self._sort_objects()
+
+    def remove_game_object(self, game_object: GameObject) -> None:
+        """
+        Remove a *runtime GameObject from the scene and call `on_remove` on its components.
+
+        Args:
+            game_object (GameObject): The GameObject to remove.
+        """
+        if game_object in self.runtime_objects:
+            for comp in game_object.components:
+                if hasattr(comp, "on_remove"):
+                    comp.on_remove()
+            self.runtime_objects.remove(game_object)
+            del game_object
+            self._sort_objects()
+
+    def get_all_components_of_type(self, component_type):
+        components = []
+        for go in self.sorted_objects:
+            components = components + go.get_all_components_of_type(component_type)
+        return components
+
+    def update(self, dt: float) -> None:
+        """
+        Update all GameObjects (initial and runtime) and CollisionManagers in the scene.
+
+        Args:
+            dt (float): Delta time since last frame.
+        """
+        for obj in self.sorted_objects:
+            obj.update(dt)
+
+        self.trigger_collision_manager.update(dt)
+
+    def fixed_update(self, dt: float) -> None:
+        """
+        Fixed timestep update for physics or deterministic logic.
+        Calls `fixed_update` on all GameObjects (initial and runtime).
+
+        Args:
+            dt (float): Fixed delta time.
+        """
+        self.physics_space.step(dt)
+
+        for obj in self.sorted_objects:
+            obj.fixed_update(dt)
+
+    def render(self, surface) -> None:
+        """
+        Render all GameObjects in the scene to the given surface in order of z_index.
+
+        Args:
+            surface: The pygame surface to render onto.
+        """
+        for obj in self.sorted_objects:
+            obj.render(surface)
+
+    def _sort_objects(self):
+        # Sort game objects by z_index (default 0)
+        self.sorted_objects = self.initial_objects + self.runtime_objects
+        self.sorted_objects.sort(key=attrgetter("z_index"))
 
     def get_window_size(self) -> tuple[int, int]:
         """
@@ -182,7 +178,7 @@ class Scene:
         return self.engine.window.get_size()
 
     def __repr__(self):
-        return f"<Scene name='{self.name}', objects={len(self.game_objects)}>"
+        return f"<Scene name='{self.name}', objects={len(self.sorted_objects)}>"
 
 
 class SceneManager:
@@ -194,16 +190,9 @@ class SceneManager:
         self.scenes: dict[str, Scene] = {}
         self.active_scene: Scene | None = None
 
-    def start_active_scene(self):
-        """
-        Call start() on the active scene if it exists.
-        """
-        if self.active_scene:
-            self.active_scene.start()
-
     def add_scene(self, scene: Scene, engine) -> None:
         """
-        Add a scene to the manager and assign it an cogworks reference.
+        Add a scene to the manager and assign it an engine reference.
 
         Args:
             scene (Scene): The scene to add.
@@ -224,20 +213,19 @@ class SceneManager:
         """
         if scene_name in self.scenes:
             self.active_scene = self.scenes[scene_name]
+            self.active_scene.start()
         else:
             raise ValueError(f"Scene '{scene_name}' not found in SceneManager.")
 
-    def _restart_active_scene(self):
-        self.active_scene.restart()
+    def start_active_scene(self):
+        if self.active_scene:
+            self.active_scene.start()
 
     def change_active_scene(self, scene_name: str) -> None:
         """Change the currently active scene by name."""
-        self._restart_active_scene()
-        self.active_scene.stop_scene()
+        if self.active_scene:
+            self.active_scene.stop()
         self.set_active_scene(scene_name)
-        self.start_active_scene()
-        self._restart_active_scene()
-
 
     def update(self, dt: float) -> None:
         """
